@@ -83,3 +83,10 @@ class ApiSpaces(ApiBase):
         return self.build_route(
             "spaces/{space_name}/production_repository".format(**locals())
         )
+
+    def add_repository_relationship(self, space_name: str):
+        return self.build_route(f"spaces/{space_name}/repository_relationships")
+
+    def repository_relationship(self, space_name: str, deployment_type: str):
+        return self.build_route(f"spaces/{space_name}/repository_relationships/{deployment_type}")
+
