@@ -77,6 +77,7 @@ class CreateAccountRequest:
             email: str,
             password: str,
             phone_number: str,
+            utm_campaign: str = "",
     ):
         self.phone_number = phone_number
         self.password = password
@@ -84,6 +85,7 @@ class CreateAccountRequest:
         self.last_name = last_name
         self.first_name = first_name
         self.account_name = account_name
+        self.utm_campaign = utm_campaign
 
 
 class UpdateSpaceRequest:
@@ -107,3 +109,10 @@ class UpdateK8SComputeServiceInSpaceRequest:
 class AwsCloudProviderSettingsModel:
     def __init__(self, sidecar_image_param_name: Optional[str]):
         self.sidecar_image_param_name = sidecar_image_param_name
+
+
+class InsidedTokenResponseModel:
+    def __init__(self, access_token: str, expires_in: int, token_type: str):
+        self. access_token = access_token
+        self. token_type = token_type
+        self.expires_in = expires_in
