@@ -33,6 +33,30 @@ class TheGateway:
         )
         GatewayUtils.handle_response(response=response, return_codes=[200])
 
+    def account_request_colony_account(self, req: CreateAccountRequest):
+        response = self._session.post(
+            url="{}/api/accounts/account_request".format(self.api_address),
+            json={
+                "account_name": req.account_name,
+                "first_name": req.first_name,
+                "last_name": req.last_name,
+                "email": req.email,
+                "password": req.password,
+                "phone_number": req.phone_number,
+                "utm_campaign": req.utm_campaign,
+            },
+        )
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+
+    def account_finalize_colony_account(self, token):
+        response = self._session.post(
+            url="{}/api/accounts/account_finalize".format(self.api_address),
+            json={
+                "secret": token
+            },
+        )
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+
     def account_login(self, account: str, email: str, password: str) -> TokenResponse:
         response = self._session.post(
             url="{}/api/accounts/{}/login".format(self.api_address, account),
@@ -83,9 +107,10 @@ class TheGateway:
         GatewayUtils.handle_response(response=response, return_codes=[200])
 
     def get_access_token_with_refresh_token(self, access_token: str, refresh_token: str):
-        url = f"{self.api_address}/api/token/refresh/{refresh_token}".format(**locals())
-        response = self._session.get(
-            url=url, headers=self._get_headers(access_token=access_token)
+        url = f"{self.api_address}/api/token/refresh".format(**locals())
+        data = {'refresh_token': refresh_token}
+        response = self._session.post(
+            url=url, headers=self._get_headers(access_token=access_token), json=data
         )
         GatewayUtils.handle_response(response=response, return_codes=[200])
 
